src/server/plugins/postgresql/vfs.h

branch
webdav
changeset 305
4db64fe30588
parent 304
33911d44111d
child 311
e676ed461b5b
--- a/src/server/plugins/postgresql/vfs.h	Wed Apr 20 17:48:33 2022 +0200
+++ b/src/server/plugins/postgresql/vfs.h	Thu Apr 21 17:16:49 2022 +0200
@@ -72,17 +72,18 @@
  * 
  * Only absolute paths are supported, therefore path[0] must be '/'
  * 
  * If the resource is not found, ctx->vfs_errno is set to ENOENT
  */
 int pg_resolve_path(
-        VFSContext *ctx,
+        PGconn *connection,
         const char *path,
         int64_t *parent_id,
         int64_t *resource_id,
         Oid *oid,
         const char **resource_name,
         WSBool *iscollection,
-        struct stat *s);
+        struct stat *s,
+        int *res_errno);
 
 void pg_set_stat(
         struct stat *s,
@@ -72,17 +72,18 @@
  * Only absolute paths are supported, therefore path[0] must be '/'
  * 
- * If the resource is not found, ctx->vfs_errno is set to ENOENT
+ * If the resource is not found, res_errno is set to ENOENT
  */
 int pg_resolve_path(

mercurial